package cz.fidentis.analyst.symmetry;

/**
 * Symmetry plane.
 * 
 * @author Natalia Bebjakova
 */
public class Plane {
   
    public double a;
    public double b;
    public double c;
    public double d;

    /**
     * Creates new plane 
     * 
     * @param a a coordinate 
     * @param b b coordinate
     * @param c c coordinate
     * @param d d coordinate
     */
    public Plane(double a, double b, double c, double d) {
        this.a = a;
        this.b = b;
        this.c = c;
        this.d = d;
    }
    
    /**
     * Copy constructor.
     * @param plane original plane
     * @throws IllegalArgumentExpcption if the @code{plane} argument is null
     */
    public Plane(Plane plane) {
        if (plane == null) {
            throw new IllegalArgumentException();
        }
        a = plane.a;
        b = plane.b;
        c = plane.c;
        d = plane.d;
    }
    
    /**
     * Normalize the plane
     */
    public void normalize() {
        double normalLength = Math.sqrt(a * a + b * b + c * c);
        
        a /= normalLength;
        b /= normalLength;
        c /= normalLength;
        d /= normalLength;
    }
    
    /**
     * Returns string description of the plane
     * 
     * @return description of the plane
     */
    @Override
    public String toString(){
        return "APPROXIMATE PLANE:\n" + a + "\n" + b + "\n" + c + "\n" + d + "\n";
    }
}
